changeset 159:3f2ec4314855

Changed matching string enterprise->enterprise35, so it matches again the version strings in all three files, necessary since kdesvn r816025 | pradeepto | 2008-06-03 06:45:13 +0200 (Di, 03 Jun 2008)Cosmetics.
author Bernhard Reiter <bernhard@intevation.de>
date Thu, 19 Jun 2008 10:13:39 +0000
parents 8ec9ed76d67b
children 017179427c7f
files recipes/kde_enterprise_3_5/kdepim.py
diffstat 1 files changed, 6 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/recipes/kde_enterprise_3_5/kdepim.py	Tue Jun 17 18:06:21 2008 +0000
+++ b/recipes/kde_enterprise_3_5/kdepim.py	Thu Jun 19 10:13:39 2008 +0000
@@ -5,7 +5,8 @@
 # This program is free software under the GPL (>=v2)
 # Read the file COPYING coming with the software for details.
 
 """Packager that builds KDE-PIM debian packages from the enterprise branch"""
 
 import os
 import time
@@ -41,11 +42,12 @@
     def update_version_numbers(self, pkgbasedir):
         """Overrides the inherited method to update version numbers in the code
         """
-        versionstring = "(enterprise %s)" % self.enterprise_version
+        versionstring = "(enterprise35 %s)" % self.enterprise_version
         for versionfile in ["kmail/kmversion.h", "kontact/src/main.cpp",
                             "korganizer/version.h"]:
+	    #FIXME: should check successful replacements
             treepkg.util.replace_in_file(os.path.join(pkgbasedir, versionfile),
-                                         "\(enterprise ([^)]*)\)",
+                                         "\(enterprise35 ([^)]*)\)",
                                          versionstring)
 
     def do_package(self):
@@ -58,7 +60,7 @@
         self.create_tarball(origtargz, self.work_dir,
                             os.path.basename(pkgbasedir))
 
-        changemsg = ("Update to SVN enterprise branch rev. %d"
+        changemsg = ("Update to SVN enterprise35 branch rev. %d"
                      % (self.revision,))
         self.copy_debian_directory(pkgbasedir, pkgbaseversion,
                                    changemsg)
@@ -5,7 +5,8 @@
 # Read the file COPYING coming with the software for details.
 
-"""Packager that builds KDE-PIM debian packages from the enterprise branch"""
+"""Packager that builds KDE-PIM debian packages from the enterprise35 branch.
+"""
 
 import os
This site is hosted by Intevation GmbH (Datenschutzerklärung und Impressum | Privacy Policy and Imprint)